#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IFileHosting_VERSION = "3.1.28078"

class IFileHosting(BaseEndpoint):
	def __init__(self, apiKey, url ,domainUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/filehosting/{domainUid}'
		self.domainUid_ = domainUid
		self.base = self.base.replace('{domainUid}',domainUid)

	def store (self, path , document ):
		postUri = "/{path}";
		__data__ = None
		postUri = postUri.replace("{path}",path);
		__data__ = serder.STREAM.encode(document)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def list (self, path ):
		postUri = "/_list";
		__data__ = None
		queryParams = {  'path': path   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		from netbluemind.filehosting.api.FileHostingItem import FileHostingItem
		from netbluemind.filehosting.api.FileHostingItem import __FileHostingItemSerDer__
		return self.handleResult__(serder.ListSerDer(__FileHostingItemSerDer__()), response)
	def delete (self, path ):
		postUri = "/{path}";
		__data__ = None
		postUri = postUri.replace("{path}",path);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getComplete (self, uid ):
		postUri = "/{uid}/_complete";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		from netbluemind.filehosting.api.FileHostingItem import FileHostingItem
		from netbluemind.filehosting.api.FileHostingItem import __FileHostingItemSerDer__
		return self.handleResult__(__FileHostingItemSerDer__(), response)
	def getConfiguration (self):
		postUri = "/_config";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		from netbluemind.filehosting.api.Configuration import Configuration
		from netbluemind.filehosting.api.Configuration import __ConfigurationSerDer__
		return self.handleResult__(__ConfigurationSerDer__(), response)
	def find (self, query ):
		postUri = "/_find";
		__data__ = None
		queryParams = {  'query': query   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		from netbluemind.filehosting.api.FileHostingItem import FileHostingItem
		from netbluemind.filehosting.api.FileHostingItem import __FileHostingItemSerDer__
		return self.handleResult__(serder.ListSerDer(__FileHostingItemSerDer__()), response)
	def unShare (self, url ):
		postUri = "/{url}/unshare";
		__data__ = None
		postUri = postUri.replace("{url}",url);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def get (self, path ):
		postUri = "/{path}/_content";
		__data__ = None
		postUri = postUri.replace("{path}",path);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.STREAM, response)
	def getSharedFile (self, uid ):
		postUri = "/{uid}/_public";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.STREAM, response)
	def share (self, path , downloadLimit , expirationDate ):
		postUri = "/{path}/share";
		__data__ = None
		postUri = postUri.replace("{path}",path);
		queryParams = {   'downloadLimit': downloadLimit  , 'expirationDate': expirationDate   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		from netbluemind.filehosting.api.FileHostingPublicLink import FileHostingPublicLink
		from netbluemind.filehosting.api.FileHostingPublicLink import __FileHostingPublicLinkSerDer__
		return self.handleResult__(__FileHostingPublicLinkSerDer__(), response)
	def info (self):
		postUri = "/_info";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFileHosting_VERSION}, data = json.dumps(__data__));
		from netbluemind.filehosting.api.FileHostingInfo import FileHostingInfo
		from netbluemind.filehosting.api.FileHostingInfo import __FileHostingInfoSerDer__
		return self.handleResult__(__FileHostingInfoSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ExternalSystem :
	def __init__( self):
		self.identifier = None
		self.description = None
		self.authKind = None
		pass

class __ExternalSystemSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ExternalSystem()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		identifierValue = value['identifier']
		instance.identifier = serder.STRING.parse(identifierValue)
		descriptionValue = value['description']
		instance.description = serder.STRING.parse(descriptionValue)
		from netbluemind.system.api.ExternalSystemAuthKind import ExternalSystemAuthKind
		from netbluemind.system.api.ExternalSystemAuthKind import __ExternalSystemAuthKindSerDer__
		authKindValue = value['authKind']
		instance.authKind = __ExternalSystemAuthKindSerDer__().parse(authKindValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		identifierValue = value.identifier
		instance["identifier"] = serder.STRING.encode(identifierValue)
		descriptionValue = value.description
		instance["description"] = serder.STRING.encode(descriptionValue)
		from netbluemind.system.api.ExternalSystemAuthKind import ExternalSystemAuthKind
		from netbluemind.system.api.ExternalSystemAuthKind import __ExternalSystemAuthKindSerDer__
		authKindValue = value.authKind
		instance["authKind"] = __ExternalSystemAuthKindSerDer__().encode(authKindValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElementAttendee :
	def __init__( self):
		self.cutype = None
		self.member = None
		self.role = None
		self.partStatus = None
		self.rsvp = None
		self.delTo = None
		self.delFrom = None
		self.sentBy = None
		self.commonName = None
		self.dir = None
		self.lang = None
		self.mailto = None
		self.uri = None
		self.internal = None
		self.responseComment = None
		pass

class __ICalendarElementAttendeeSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ICalendarElementAttendee()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.icalendar.api.ICalendarElementCUType import ICalendarElementCUType
		from netbluemind.icalendar.api.ICalendarElementCUType import __ICalendarElementCUTypeSerDer__
		cutypeValue = value['cutype']
		instance.cutype = __ICalendarElementCUTypeSerDer__().parse(cutypeValue)
		memberValue = value['member']
		instance.member = serder.STRING.parse(memberValue)
		from netbluemind.icalendar.api.ICalendarElementRole import ICalendarElementRole
		from netbluemind.icalendar.api.ICalendarElementRole import __ICalendarElementRoleSerDer__
		roleValue = value['role']
		instance.role = __ICalendarElementRoleSerDer__().parse(roleValue)
		from netbluemind.icalendar.api.ICalendarElementParticipationStatus import ICalendarElementParticipationStatus
		from netbluemind.icalendar.api.ICalendarElementParticipationStatus import __ICalendarElementParticipationStatusSerDer__
		partStatusValue = value['partStatus']
		instance.partStatus = __ICalendarElementParticipationStatusSerDer__().parse(partStatusValue)
		rsvpValue = value['rsvp']
		instance.rsvp = serder.BOOLEAN.parse(rsvpValue)
		delToValue = value['delTo']
		instance.delTo = serder.STRING.parse(delToValue)
		delFromValue = value['delFrom']
		instance.delFrom = serder.STRING.parse(delFromValue)
		sentByValue = value['sentBy']
		instance.sentBy = serder.STRING.parse(sentByValue)
		commonNameValue = value['commonName']
		instance.commonName = serder.STRING.parse(commonNameValue)
		dirValue = value['dir']
		instance.dir = serder.STRING.parse(dirValue)
		langValue = value['lang']
		instance.lang = serder.STRING.parse(langValue)
		mailtoValue = value['mailto']
		instance.mailto = serder.STRING.parse(mailtoValue)
		uriValue = value['uri']
		instance.uri = serder.STRING.parse(uriValue)
		internalValue = value['internal']
		instance.internal = serder.BOOLEAN.parse(internalValue)
		responseCommentValue = value['responseComment']
		instance.responseComment = serder.STRING.parse(responseCommentValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.icalendar.api.ICalendarElementCUType import ICalendarElementCUType
		from netbluemind.icalendar.api.ICalendarElementCUType import __ICalendarElementCUTypeSerDer__
		cutypeValue = value.cutype
		instance["cutype"] = __ICalendarElementCUTypeSerDer__().encode(cutypeValue)
		memberValue = value.member
		instance["member"] = serder.STRING.encode(memberValue)
		from netbluemind.icalendar.api.ICalendarElementRole import ICalendarElementRole
		from netbluemind.icalendar.api.ICalendarElementRole import __ICalendarElementRoleSerDer__
		roleValue = value.role
		instance["role"] = __ICalendarElementRoleSerDer__().encode(roleValue)
		from netbluemind.icalendar.api.ICalendarElementParticipationStatus import ICalendarElementParticipationStatus
		from netbluemind.icalendar.api.ICalendarElementParticipationStatus import __ICalendarElementParticipationStatusSerDer__
		partStatusValue = value.partStatus
		instance["partStatus"] = __ICalendarElementParticipationStatusSerDer__().encode(partStatusValue)
		rsvpValue = value.rsvp
		instance["rsvp"] = serder.BOOLEAN.encode(rsvpValue)
		delToValue = value.delTo
		instance["delTo"] = serder.STRING.encode(delToValue)
		delFromValue = value.delFrom
		instance["delFrom"] = serder.STRING.encode(delFromValue)
		sentByValue = value.sentBy
		instance["sentBy"] = serder.STRING.encode(sentByValue)
		commonNameValue = value.commonName
		instance["commonName"] = serder.STRING.encode(commonNameValue)
		dirValue = value.dir
		instance["dir"] = serder.STRING.encode(dirValue)
		langValue = value.lang
		instance["lang"] = serder.STRING.encode(langValue)
		mailtoValue = value.mailto
		instance["mailto"] = serder.STRING.encode(mailtoValue)
		uriValue = value.uri
		instance["uri"] = serder.STRING.encode(uriValue)
		internalValue = value.internal
		instance["internal"] = serder.BOOLEAN.encode(internalValue)
		responseCommentValue = value.responseComment
		instance["responseComment"] = serder.STRING.encode(responseCommentValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class MailFilterRule :
	def __init__( self):
		self.criteria = None
		self.star = None
		self.read = None
		self.delete = None
		self.discard = None
		self.forward = None
		self.deliver = None
		self.active = None
		pass

class __MailFilterRuleSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = MailFilterRule()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		criteriaValue = value['criteria']
		instance.criteria = serder.STRING.parse(criteriaValue)
		starValue = value['star']
		instance.star = serder.BOOLEAN.parse(starValue)
		readValue = value['read']
		instance.read = serder.BOOLEAN.parse(readValue)
		deleteValue = value['delete']
		instance.delete = serder.BOOLEAN.parse(deleteValue)
		discardValue = value['discard']
		instance.discard = serder.BOOLEAN.parse(discardValue)
		from netbluemind.mailbox.api.MailFilterForwarding import MailFilterForwarding
		from netbluemind.mailbox.api.MailFilterForwarding import __MailFilterForwardingSerDer__
		forwardValue = value['forward']
		instance.forward = __MailFilterForwardingSerDer__().parse(forwardValue)
		deliverValue = value['deliver']
		instance.deliver = serder.STRING.parse(deliverValue)
		activeValue = value['active']
		instance.active = serder.BOOLEAN.parse(activeValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		criteriaValue = value.criteria
		instance["criteria"] = serder.STRING.encode(criteriaValue)
		starValue = value.star
		instance["star"] = serder.BOOLEAN.encode(starValue)
		readValue = value.read
		instance["read"] = serder.BOOLEAN.encode(readValue)
		deleteValue = value.delete
		instance["delete"] = serder.BOOLEAN.encode(deleteValue)
		discardValue = value.discard
		instance["discard"] = serder.BOOLEAN.encode(discardValue)
		from netbluemind.mailbox.api.MailFilterForwarding import MailFilterForwarding
		from netbluemind.mailbox.api.MailFilterForwarding import __MailFilterForwardingSerDer__
		forwardValue = value.forward
		instance["forward"] = __MailFilterForwardingSerDer__().encode(forwardValue)
		deliverValue = value.deliver
		instance["deliver"] = serder.STRING.encode(deliverValue)
		activeValue = value.active
		instance["active"] = serder.BOOLEAN.encode(activeValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VTodoQuery :
	def __init__( self):
		self.from_ = None
		self.size = None
		self.query = None
		self.escapeQuery = None
		self.todoUid = None
		self.dateMin = None
		self.dateMax = None
		pass

class __VTodoQuerySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VTodoQuery()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from_Value = value['from']
		instance.from_ = serder.INT.parse(from_Value)
		sizeValue = value['size']
		instance.size = serder.INT.parse(sizeValue)
		queryValue = value['query']
		instance.query = serder.STRING.parse(queryValue)
		escapeQueryValue = value['escapeQuery']
		instance.escapeQuery = serder.BOOLEAN.parse(escapeQueryValue)
		todoUidValue = value['todoUid']
		instance.todoUid = serder.STRING.parse(todoUidValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dateMinValue = value['dateMin']
		instance.dateMin = __BmDateTimeSerDer__().parse(dateMinValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dateMaxValue = value['dateMax']
		instance.dateMax = __BmDateTimeSerDer__().parse(dateMaxValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from_Value = value.from_
		instance["from"] = serder.INT.encode(from_Value)
		sizeValue = value.size
		instance["size"] = serder.INT.encode(sizeValue)
		queryValue = value.query
		instance["query"] = serder.STRING.encode(queryValue)
		escapeQueryValue = value.escapeQuery
		instance["escapeQuery"] = serder.BOOLEAN.encode(escapeQueryValue)
		todoUidValue = value.todoUid
		instance["todoUid"] = serder.STRING.encode(todoUidValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dateMinValue = value.dateMin
		instance["dateMin"] = __BmDateTimeSerDer__().encode(dateMinValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dateMaxValue = value.dateMax
		instance["dateMax"] = __BmDateTimeSerDer__().encode(dateMaxValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class CalendarSettingsData :
	def __init__( self):
		self.workingDays = None
		self.dayStart = None
		self.dayEnd = None
		self.minDuration = None
		self.timezoneId = None
		pass

class __CalendarSettingsDataSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = CalendarSettingsData()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.calendar.api.CalendarSettingsDataDay import CalendarSettingsDataDay
		from netbluemind.calendar.api.CalendarSettingsDataDay import __CalendarSettingsDataDaySerDer__
		workingDaysValue = value['workingDays']
		instance.workingDays = serder.ListSerDer(__CalendarSettingsDataDaySerDer__()).parse(workingDaysValue)
		dayStartValue = value['dayStart']
		instance.dayStart = serder.INT.parse(dayStartValue)
		dayEndValue = value['dayEnd']
		instance.dayEnd = serder.INT.parse(dayEndValue)
		minDurationValue = value['minDuration']
		instance.minDuration = serder.INT.parse(minDurationValue)
		timezoneIdValue = value['timezoneId']
		instance.timezoneId = serder.STRING.parse(timezoneIdValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.calendar.api.CalendarSettingsDataDay import CalendarSettingsDataDay
		from netbluemind.calendar.api.CalendarSettingsDataDay import __CalendarSettingsDataDaySerDer__
		workingDaysValue = value.workingDays
		instance["workingDays"] = serder.ListSerDer(__CalendarSettingsDataDaySerDer__()).encode(workingDaysValue)
		dayStartValue = value.dayStart
		instance["dayStart"] = serder.INT.encode(dayStartValue)
		dayEndValue = value.dayEnd
		instance["dayEnd"] = serder.INT.encode(dayEndValue)
		minDurationValue = value.minDuration
		instance["minDuration"] = serder.INT.encode(minDurationValue)
		timezoneIdValue = value.timezoneId
		instance["timezoneId"] = serder.STRING.encode(timezoneIdValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.directory.api.DirBaseValue import DirBaseValue
from netbluemind.directory.api.DirBaseValue import __DirBaseValueSerDer__
class User (DirBaseValue):
	def __init__( self):
		DirBaseValue.__init__(self)
		self.login = None
		self.password = None
		self.contactInfos = None
		self.routing = None
		self.quota = None
		self.properties = None
		pass

class __UserSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = User()
		__DirBaseValueSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		loginValue = value['login']
		instance.login = serder.STRING.parse(loginValue)
		passwordValue = value['password']
		instance.password = serder.STRING.parse(passwordValue)
		from netbluemind.addressbook.api.VCard import VCard
		from netbluemind.addressbook.api.VCard import __VCardSerDer__
		contactInfosValue = value['contactInfos']
		instance.contactInfos = __VCardSerDer__().parse(contactInfosValue)
		from netbluemind.mailbox.api.MailboxRouting import MailboxRouting
		from netbluemind.mailbox.api.MailboxRouting import __MailboxRoutingSerDer__
		routingValue = value['routing']
		instance.routing = __MailboxRoutingSerDer__().parse(routingValue)
		quotaValue = value['quota']
		instance.quota = serder.INT.parse(quotaValue)
		propertiesValue = value['properties']
		instance.properties = serder.MapSerDer(serder.STRING).parse(propertiesValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__DirBaseValueSerDer__().encodeInternal(value,instance)

		loginValue = value.login
		instance["login"] = serder.STRING.encode(loginValue)
		passwordValue = value.password
		instance["password"] = serder.STRING.encode(passwordValue)
		from netbluemind.addressbook.api.VCard import VCard
		from netbluemind.addressbook.api.VCard import __VCardSerDer__
		contactInfosValue = value.contactInfos
		instance["contactInfos"] = __VCardSerDer__().encode(contactInfosValue)
		from netbluemind.mailbox.api.MailboxRouting import MailboxRouting
		from netbluemind.mailbox.api.MailboxRouting import __MailboxRoutingSerDer__
		routingValue = value.routing
		instance["routing"] = __MailboxRoutingSerDer__().encode(routingValue)
		quotaValue = value.quota
		instance["quota"] = serder.INT.encode(quotaValue)
		propertiesValue = value.properties
		instance["properties"] = serder.MapSerDer(serder.STRING).encode(propertiesValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class UpgradeReportUpgraderReport :
	def __init__( self):
		self.major = None
		self.build = None
		self.status = None
		pass

class __UpgradeReportUpgraderReportSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = UpgradeReportUpgraderReport()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		majorValue = value['major']
		instance.major = serder.INT.parse(majorValue)
		buildValue = value['build']
		instance.build = serder.INT.parse(buildValue)
		from netbluemind.system.api.UpgradeReportStatus import UpgradeReportStatus
		from netbluemind.system.api.UpgradeReportStatus import __UpgradeReportStatusSerDer__
		statusValue = value['status']
		instance.status = __UpgradeReportStatusSerDer__().parse(statusValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		majorValue = value.major
		instance["major"] = serder.INT.encode(majorValue)
		buildValue = value.build
		instance["build"] = serder.INT.encode(buildValue)
		from netbluemind.system.api.UpgradeReportStatus import UpgradeReportStatus
		from netbluemind.system.api.UpgradeReportStatus import __UpgradeReportStatusSerDer__
		statusValue = value.status
		instance["status"] = __UpgradeReportStatusSerDer__().encode(statusValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.icalendar.api.ICalendarElement import ICalendarElement
from netbluemind.icalendar.api.ICalendarElement import __ICalendarElementSerDer__
class VEvent (ICalendarElement):
	def __init__( self):
		ICalendarElement.__init__(self)
		self.dtend = None
		self.transparency = None
		pass

class __VEventSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VEvent()
		__ICalendarElementSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dtendValue = value['dtend']
		instance.dtend = __BmDateTimeSerDer__().parse(dtendValue)
		from netbluemind.calendar.api.VEventTransparency import VEventTransparency
		from netbluemind.calendar.api.VEventTransparency import __VEventTransparencySerDer__
		transparencyValue = value['transparency']
		instance.transparency = __VEventTransparencySerDer__().parse(transparencyValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__ICalendarElementSerDer__().encodeInternal(value,instance)

		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dtendValue = value.dtend
		instance["dtend"] = __BmDateTimeSerDer__().encode(dtendValue)
		from netbluemind.calendar.api.VEventTransparency import VEventTransparency
		from netbluemind.calendar.api.VEventTransparency import __VEventTransparencySerDer__
		transparencyValue = value.transparency
		instance["transparency"] = __VEventTransparencySerDer__().encode(transparencyValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class DomainTemplateDescriptionI18NDescription :
	def __init__( self):
		self.lang = None
		self.text = None
		self.helpText = None
		pass

class __DomainTemplateDescriptionI18NDescriptionSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = DomainTemplateDescriptionI18NDescription()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		langValue = value['lang']
		instance.lang = serder.STRING.parse(langValue)
		textValue = value['text']
		instance.text = serder.STRING.parse(textValue)
		helpTextValue = value['helpText']
		instance.helpText = serder.STRING.parse(helpTextValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		langValue = value.lang
		instance["lang"] = serder.STRING.encode(langValue)
		textValue = value.text
		instance["text"] = serder.STRING.encode(textValue)
		helpTextValue = value.helpText
		instance["helpText"] = serder.STRING.encode(helpTextValue)
		return instance




import base64
from base64 import b64decode
from base64 import b64encode
from  datetime import datetime

class ByteArraySerDer:

	@classmethod
	def parse(cls, value):
		if value == None:
			return None
		else:
			return b64decode(value)

	@classmethod
	def encode(cls, value):
		if value == None:
			return None
		else:
			return b64encode(value)
	
class STRING:

	@classmethod
	def parse(cls, value):
		return value

	@classmethod
	def encode(cls, value):
		return value

	
class LONG:

	@classmethod
	def parse(cls, value):
		return value

	@classmethod
	def encode(cls, value):
		return value

	
class DOUBLE:

	@classmethod
	def parse(cls, value):
		return value

	@classmethod
	def encode(cls, value):
		return value


class INT:

	@classmethod
	def parse(cls, value):
		return value

	@classmethod
	def encode(cls, value):
		return value

class DATE:

	@classmethod
	def parse(cls, value):
		if value == None:
			return None
		else:
			return datetime.fromtimestamp(value/1000)

	@classmethod
	def encode(cls, value):
		if value == None:
			return None
		else:
			return (value - datetime(1970, 1, 1)).total_seconds() * 1000

class BOOLEAN:

	@classmethod
	def parse(cls, value):
		return value

	@classmethod
	def encode(cls, value):
		return value

class VOID:

	@classmethod
	def parse(cls, value):
		return value

	@classmethod
	def encode(cls, value):
		return value

class MapSerDer:
	def __init__(self, serder):
		self.serder = serder

	def parse(self, value):
		if value == None:
			return None

		ret = dict()
		for v in value.keys():
			ret[v] = self.serder.parse( value[v] )
		return ret


	def encode(self, value):
		if value == None:
			return None

		ret = dict()
		for v in value.keys():
			ret[v] = self.serder.encode( value[v] )
		return ret


class CollectionSerDer:
	def __init__(self, serder):
		self.serder = serder


	def parse(self, value):
		if value == None:
			return None

		ret = []
		for v in value:
			ret.append( self.serder.parse( v) )
		return ret

	def encode(self, value):
		if value == None:
			return None

		ret = []
		for v in value:
			ret.append( self.serder.encode( v) )
		return ret

class ListSerDer:
	def __init__(self, serder):
		self.serder = serder

	def parse(self, value):
		if value == None:
			return None

		ret = []
		for v in value:
			ret.append( self.serder.parse( v) )
		return ret

	def encode(self, value):
		if value == None:
			return None

		ret = []
		for v in value:
			ret.append( self.serder.encode( v) )
		return ret

class ArraySerDer:
	def __init__(self, serder):
		self.serder = serder

	def parse(self, value):
		if value == None:
			return None

		ret = []
		for v in value:
			ret.append( self.serder.parse( v) )
		return ret

	def encode(self, value):
		if value == None:
			return None

		ret = []
		for v in value:
			ret.append( self.serder.encode( v) )
		return ret


class SetSerDer:
	def __init__(self, serder):
		self.serder = serder

	def parse(self, value):
		if value == None:
			return None

		ret = []
		for v in value:
			ret.append( self.serder.parse( v) )
		return ret

	def encode(self, value):
		if value == None:
			return None

		ret = []
		for v in value:
			ret.append( self.serder.encode( v) )
		return ret



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Reminder :
	def __init__( self):
		self.user = None
		self.todo = None
		self.valarm = None
		pass

class __ReminderSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Reminder()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.user.api.User import User
		from netbluemind.user.api.User import __UserSerDer__
		userValue = value['user']
		instance.user = __UserSerDer__().parse(userValue)
		from netbluemind.todolist.api.VTodo import VTodo
		from netbluemind.todolist.api.VTodo import __VTodoSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		todoValue = value['todo']
		instance.todo = __ItemValueSerDer__(__VTodoSerDer__()).parse(todoValue)
		from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
		from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
		valarmValue = value['valarm']
		instance.valarm = __ICalendarElementVAlarmSerDer__().parse(valarmValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.user.api.User import User
		from netbluemind.user.api.User import __UserSerDer__
		userValue = value.user
		instance["user"] = __UserSerDer__().encode(userValue)
		from netbluemind.todolist.api.VTodo import VTodo
		from netbluemind.todolist.api.VTodo import __VTodoSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		todoValue = value.todo
		instance["todo"] = __ItemValueSerDer__(__VTodoSerDer__()).encode(todoValue)
		from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
		from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
		valarmValue = value.valarm
		instance["valarm"] = __ICalendarElementVAlarmSerDer__().encode(valarmValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class LogEntry :
	def __init__( self):
		self.timestamp = None
		self.severity = None
		self.locale = None
		self.content = None
		self.offset = None
		pass

class __LogEntrySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = LogEntry()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		timestampValue = value['timestamp']
		instance.timestamp = serder.LONG.parse(timestampValue)
		from netbluemind.scheduledjob.api.LogLevel import LogLevel
		from netbluemind.scheduledjob.api.LogLevel import __LogLevelSerDer__
		severityValue = value['severity']
		instance.severity = __LogLevelSerDer__().parse(severityValue)
		localeValue = value['locale']
		instance.locale = serder.STRING.parse(localeValue)
		contentValue = value['content']
		instance.content = serder.STRING.parse(contentValue)
		offsetValue = value['offset']
		instance.offset = serder.INT.parse(offsetValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		timestampValue = value.timestamp
		instance["timestamp"] = serder.LONG.encode(timestampValue)
		from netbluemind.scheduledjob.api.LogLevel import LogLevel
		from netbluemind.scheduledjob.api.LogLevel import __LogLevelSerDer__
		severityValue = value.severity
		instance["severity"] = __LogLevelSerDer__().encode(severityValue)
		localeValue = value.locale
		instance["locale"] = serder.STRING.encode(localeValue)
		contentValue = value.content
		instance["content"] = serder.STRING.encode(contentValue)
		offsetValue = value.offset
		instance["offset"] = serder.INT.encode(offsetValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class DataProtectGeneration :
	def __init__( self):
		self.id = None
		self.protectionTime = None
		self.blueMind = None
		self.withWarnings = None
		self.withErrors = None
		self.parts = None
		pass

class __DataProtectGenerationSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = DataProtectGeneration()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		idValue = value['id']
		instance.id = serder.INT.parse(idValue)
		protectionTimeValue = value['protectionTime']
		instance.protectionTime = serder.DATE.parse(protectionTimeValue)
		from netbluemind.core.api.VersionInfo import VersionInfo
		from netbluemind.core.api.VersionInfo import __VersionInfoSerDer__
		blueMindValue = value['blueMind']
		instance.blueMind = __VersionInfoSerDer__().parse(blueMindValue)
		withWarningsValue = value['withWarnings']
		instance.withWarnings = serder.BOOLEAN.parse(withWarningsValue)
		withErrorsValue = value['withErrors']
		instance.withErrors = serder.BOOLEAN.parse(withErrorsValue)
		from netbluemind.dataprotect.api.PartGeneration import PartGeneration
		from netbluemind.dataprotect.api.PartGeneration import __PartGenerationSerDer__
		partsValue = value['parts']
		instance.parts = serder.ListSerDer(__PartGenerationSerDer__()).parse(partsValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		idValue = value.id
		instance["id"] = serder.INT.encode(idValue)
		protectionTimeValue = value.protectionTime
		instance["protectionTime"] = serder.DATE.encode(protectionTimeValue)
		from netbluemind.core.api.VersionInfo import VersionInfo
		from netbluemind.core.api.VersionInfo import __VersionInfoSerDer__
		blueMindValue = value.blueMind
		instance["blueMind"] = __VersionInfoSerDer__().encode(blueMindValue)
		withWarningsValue = value.withWarnings
		instance["withWarnings"] = serder.BOOLEAN.encode(withWarningsValue)
		withErrorsValue = value.withErrors
		instance["withErrors"] = serder.BOOLEAN.encode(withErrorsValue)
		from netbluemind.dataprotect.api.PartGeneration import PartGeneration
		from netbluemind.dataprotect.api.PartGeneration import __PartGenerationSerDer__
		partsValue = value.parts
		instance["parts"] = serder.ListSerDer(__PartGenerationSerDer__()).encode(partsValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IUser_VERSION = "3.1.28078"

class IUser(BaseEndpoint):
	def __init__(self, apiKey, url ,domainUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/users/{domainUid}'
		self.domainUid_ = domainUid
		self.base = self.base.replace('{domainUid}',domainUid)

	def setPassword (self, uid , password ):
		postUri = "/{uid}/password_";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.user.api.ChangePassword import ChangePassword
		from netbluemind.user.api.ChangePassword import __ChangePasswordSerDer__
		__data__ = __ChangePasswordSerDer__().encode(password)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getPhoto (self, uid ):
		postUri = "/{uid}/photo";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ByteArraySerDer, response)
	def allUids (self):
		postUri = "/_alluids";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ListSerDer(serder.STRING), response)
	def update (self, uid , user ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.user.api.User import User
		from netbluemind.user.api.User import __UserSerDer__
		__data__ = __UserSerDer__().encode(user)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getVCard (self, uid ):
		postUri = "/{uid}/vcard";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.addressbook.api.VCard import VCard
		from netbluemind.addressbook.api.VCard import __VCardSerDer__
		return self.handleResult__(__VCardSerDer__(), response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def deletePhoto (self, uid ):
		postUri = "/{uid}/photo";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getResolvedRoles (self, uid ):
		postUri = "/{uid}/roles_resolved";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.SetSerDer(serder.STRING), response)
	def byLogin (self, login ):
		postUri = "/byLogin/{login}";
		__data__ = None
		postUri = postUri.replace("{login}",login);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.user.api.User import User
		from netbluemind.user.api.User import __UserSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
	def byEmail (self, email ):
		postUri = "/byEmail/{email}";
		__data__ = None
		postUri = postUri.replace("{email}",email);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.user.api.User import User
		from netbluemind.user.api.User import __UserSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
	def create (self, uid , user ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.user.api.User import User
		from netbluemind.user.api.User import __UserSerDer__
		__data__ = __UserSerDer__().encode(user)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def memberOf (self, uid ):
		postUri = "/{uid}/groups";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
	def memberOfGroups (self, uid ):
		postUri = "/{uid}/groupUids";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ListSerDer(serder.STRING), response)
	def setRoles (self, uid , roles ):
		postUri = "/{uid}/roles";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.SetSerDer(serder.STRING).encode(roles)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getRoles (self, uid ):
		postUri = "/{uid}/roles";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.SetSerDer(serder.STRING), response)
	def updateVCard (self, uid , userVCard ):
		postUri = "/{uid}/vcard";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.addressbook.api.VCard import VCard
		from netbluemind.addressbook.api.VCard import __VCardSerDer__
		__data__ = __VCardSerDer__().encode(userVCard)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def checkAll (self):
		postUri = "/_check-all";
		__data__ = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def byExtId (self, extid ):
		postUri = "/byExtId/{extid}";
		__data__ = None
		postUri = postUri.replace("{extid}",extid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.user.api.User import User
		from netbluemind.user.api.User import __UserSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
	def checkAndRepair (self, uid ):
		postUri = "/{uid}/_check-and-repair";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def setExtId (self, uid , arg1 ):
		postUri = "/{uid}/_extId";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.STRING.encode(arg1)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def check (self, uid ):
		postUri = "/{uid}/_check";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def getIcon (self, uid ):
		postUri = "/{uid}/icon";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ByteArraySerDer, response)
	def getComplete (self, uid ):
		postUri = "/{uid}/complete";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.user.api.User import User
		from netbluemind.user.api.User import __UserSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
	def setPhoto (self, uid , arg1 ):
		postUri = "/{uid}/photo";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.ByteArraySerDer.encode(arg1)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getUsersWithRoles (self, roles ):
		postUri = "/_roleusers";
		__data__ = None
		__data__ = serder.ListSerDer(serder.STRING).encode(roles)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.SetSerDer(serder.STRING), response)
	def createWithExtId (self, uid , extid , user ):
		postUri = "/{uid}/{extid}/createwithextid";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		postUri = postUri.replace("{extid}",extid);
		from netbluemind.user.api.User import User
		from netbluemind.user.api.User import __UserSerDer__
		__data__ = __UserSerDer__().encode(user)

		queryParams = {     };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def checkAndRepairAll (self):
		postUri = "/_check-and-repair-all";
		__data__ = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardOrganizationalOrg :
	def __init__( self):
		self.company = None
		self.division = None
		self.department = None
		pass

class __VCardOrganizationalOrgSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardOrganizationalOrg()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		companyValue = value['company']
		instance.company = serder.STRING.parse(companyValue)
		divisionValue = value['division']
		instance.division = serder.STRING.parse(divisionValue)
		departmentValue = value['department']
		instance.department = serder.STRING.parse(departmentValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		companyValue = value.company
		instance["company"] = serder.STRING.encode(companyValue)
		divisionValue = value.division
		instance["division"] = serder.STRING.encode(divisionValue)
		departmentValue = value.department
		instance["department"] = serder.STRING.encode(departmentValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Reminder :
	def __init__( self):
		self.vevent = None
		self.valarm = None
		pass

class __ReminderSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Reminder()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.calendar.api.VEvent import VEvent
		from netbluemind.calendar.api.VEvent import __VEventSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		veventValue = value['vevent']
		instance.vevent = __ItemValueSerDer__(__VEventSerDer__()).parse(veventValue)
		from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
		from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
		valarmValue = value['valarm']
		instance.valarm = __ICalendarElementVAlarmSerDer__().parse(valarmValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.calendar.api.VEvent import VEvent
		from netbluemind.calendar.api.VEvent import __VEventSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		veventValue = value.vevent
		instance["vevent"] = __ItemValueSerDer__(__VEventSerDer__()).encode(veventValue)
		from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
		from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
		valarmValue = value.valarm
		instance["valarm"] = __ICalendarElementVAlarmSerDer__().encode(valarmValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Device :
	def __init__( self):
		self.identifier = None
		self.owner = None
		self.type = None
		self.wipeDate = None
		self.wipeBy = None
		self.unwipeDate = None
		self.unwipeBy = None
		self.isWipe = None
		self.hasPartnership = None
		self.policy = None
		self.lastSync = None
		pass

class __DeviceSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Device()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		identifierValue = value['identifier']
		instance.identifier = serder.STRING.parse(identifierValue)
		ownerValue = value['owner']
		instance.owner = serder.STRING.parse(ownerValue)
		typeValue = value['type']
		instance.type = serder.STRING.parse(typeValue)
		wipeDateValue = value['wipeDate']
		instance.wipeDate = serder.DATE.parse(wipeDateValue)
		wipeByValue = value['wipeBy']
		instance.wipeBy = serder.STRING.parse(wipeByValue)
		unwipeDateValue = value['unwipeDate']
		instance.unwipeDate = serder.DATE.parse(unwipeDateValue)
		unwipeByValue = value['unwipeBy']
		instance.unwipeBy = serder.STRING.parse(unwipeByValue)
		isWipeValue = value['isWipe']
		instance.isWipe = serder.BOOLEAN.parse(isWipeValue)
		hasPartnershipValue = value['hasPartnership']
		instance.hasPartnership = serder.BOOLEAN.parse(hasPartnershipValue)
		policyValue = value['policy']
		instance.policy = serder.INT.parse(policyValue)
		lastSyncValue = value['lastSync']
		instance.lastSync = serder.DATE.parse(lastSyncValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		identifierValue = value.identifier
		instance["identifier"] = serder.STRING.encode(identifierValue)
		ownerValue = value.owner
		instance["owner"] = serder.STRING.encode(ownerValue)
		typeValue = value.type
		instance["type"] = serder.STRING.encode(typeValue)
		wipeDateValue = value.wipeDate
		instance["wipeDate"] = serder.DATE.encode(wipeDateValue)
		wipeByValue = value.wipeBy
		instance["wipeBy"] = serder.STRING.encode(wipeByValue)
		unwipeDateValue = value.unwipeDate
		instance["unwipeDate"] = serder.DATE.encode(unwipeDateValue)
		unwipeByValue = value.unwipeBy
		instance["unwipeBy"] = serder.STRING.encode(unwipeByValue)
		isWipeValue = value.isWipe
		instance["isWipe"] = serder.BOOLEAN.encode(isWipeValue)
		hasPartnershipValue = value.hasPartnership
		instance["hasPartnership"] = serder.BOOLEAN.encode(hasPartnershipValue)
		policyValue = value.policy
		instance["policy"] = serder.INT.encode(policyValue)
		lastSyncValue = value.lastSync
		instance["lastSync"] = serder.DATE.encode(lastSyncValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ContainerChangeset :
	def __init__( self):
		self.created = None
		self.updated = None
		self.deleted = None
		self.version = None
		pass

class __ContainerChangesetSerDer__:
	def __init__( self  , T):
		self.paramSerDerT = T
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ContainerChangeset()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		createdValue = value['created']
		instance.created = serder.ListSerDer(self.paramSerDerT).parse(createdValue)
		updatedValue = value['updated']
		instance.updated = serder.ListSerDer(self.paramSerDerT).parse(updatedValue)
		deletedValue = value['deleted']
		instance.deleted = serder.ListSerDer(self.paramSerDerT).parse(deletedValue)
		versionValue = value['version']
		instance.version = serder.LONG.parse(versionValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		createdValue = value.created
		instance["created"] = serder.ListSerDer(self.paramSerDerT).encode(createdValue)
		updatedValue = value.updated
		instance["updated"] = serder.ListSerDer(self.paramSerDerT).encode(updatedValue)
		deletedValue = value.deleted
		instance["deleted"] = serder.ListSerDer(self.paramSerDerT).encode(deletedValue)
		versionValue = value.version
		instance["version"] = serder.LONG.encode(versionValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VTodoChanges :
	def __init__( self):
		self.add = None
		self.modify = None
		self.delete = None
		pass

class __VTodoChangesSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VTodoChanges()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.todolist.api.VTodoChangesItemAdd import VTodoChangesItemAdd
		from netbluemind.todolist.api.VTodoChangesItemAdd import __VTodoChangesItemAddSerDer__
		addValue = value['add']
		instance.add = serder.ListSerDer(__VTodoChangesItemAddSerDer__()).parse(addValue)
		from netbluemind.todolist.api.VTodoChangesItemModify import VTodoChangesItemModify
		from netbluemind.todolist.api.VTodoChangesItemModify import __VTodoChangesItemModifySerDer__
		modifyValue = value['modify']
		instance.modify = serder.ListSerDer(__VTodoChangesItemModifySerDer__()).parse(modifyValue)
		from netbluemind.todolist.api.VTodoChangesItemDelete import VTodoChangesItemDelete
		from netbluemind.todolist.api.VTodoChangesItemDelete import __VTodoChangesItemDeleteSerDer__
		deleteValue = value['delete']
		instance.delete = serder.ListSerDer(__VTodoChangesItemDeleteSerDer__()).parse(deleteValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.todolist.api.VTodoChangesItemAdd import VTodoChangesItemAdd
		from netbluemind.todolist.api.VTodoChangesItemAdd import __VTodoChangesItemAddSerDer__
		addValue = value.add
		instance["add"] = serder.ListSerDer(__VTodoChangesItemAddSerDer__()).encode(addValue)
		from netbluemind.todolist.api.VTodoChangesItemModify import VTodoChangesItemModify
		from netbluemind.todolist.api.VTodoChangesItemModify import __VTodoChangesItemModifySerDer__
		modifyValue = value.modify
		instance["modify"] = serder.ListSerDer(__VTodoChangesItemModifySerDer__()).encode(modifyValue)
		from netbluemind.todolist.api.VTodoChangesItemDelete import VTodoChangesItemDelete
		from netbluemind.todolist.api.VTodoChangesItemDelete import __VTodoChangesItemDeleteSerDer__
		deleteValue = value.delete
		instance["delete"] = serder.ListSerDer(__VTodoChangesItemDeleteSerDer__()).encode(deleteValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IEas_VERSION = "3.1.28078"

class IEas(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/eas'

	def getHeartbeat (self, deviceUid ):
		postUri = "/_heartbeat";
		__data__ = None
		queryParams = {  'deviceUid': deviceUid   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		from netbluemind.eas.api.Heartbeat import Heartbeat
		from netbluemind.eas.api.Heartbeat import __HeartbeatSerDer__
		return self.handleResult__(__HeartbeatSerDer__(), response)
	def setHeartbeat (self, heartbeat ):
		postUri = "/_heartbeat";
		__data__ = None
		from netbluemind.eas.api.Heartbeat import Heartbeat
		from netbluemind.eas.api.Heartbeat import __HeartbeatSerDer__
		__data__ = __HeartbeatSerDer__().encode(heartbeat)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getFolderSyncVersions (self, account ):
		postUri = "/_getFolderSync";
		__data__ = None
		from netbluemind.eas.api.Account import Account
		from netbluemind.eas.api.Account import __AccountSerDer__
		__data__ = __AccountSerDer__().encode(account)

		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.MapSerDer(serder.STRING), response)
	def setFolderSyncVersions (self, versions ):
		postUri = "/_setFolderSync";
		__data__ = None
		from netbluemind.eas.api.FolderSyncVersions import FolderSyncVersions
		from netbluemind.eas.api.FolderSyncVersions import __FolderSyncVersionsSerDer__
		__data__ = __FolderSyncVersionsSerDer__().encode(versions)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def insertPendingReset (self, account ):
		postUri = "/_reset";
		__data__ = None
		from netbluemind.eas.api.Account import Account
		from netbluemind.eas.api.Account import __AccountSerDer__
		__data__ = __AccountSerDer__().encode(account)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getSentItems (self, folderId , account ):
		postUri = "/_getSentItems/{folderId}";
		__data__ = None
		postUri = postUri.replace("{folderId}",folderId);
		from netbluemind.eas.api.Account import Account
		from netbluemind.eas.api.Account import __AccountSerDer__
		__data__ = __AccountSerDer__().encode(account)

		queryParams = {    };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		from netbluemind.eas.api.SentItem import SentItem
		from netbluemind.eas.api.SentItem import __SentItemSerDer__
		return self.handleResult__(serder.ListSerDer(__SentItemSerDer__()), response)
	def deletePendingReset (self, folderId , account ):
		postUri = "/_deletePendingReset/{folderId}";
		__data__ = None
		postUri = postUri.replace("{folderId}",folderId);
		from netbluemind.eas.api.Account import Account
		from netbluemind.eas.api.Account import __AccountSerDer__
		__data__ = __AccountSerDer__().encode(account)

		queryParams = {    };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def insertSentItems (self, sentItems ):
		postUri = "/_sentItems";
		__data__ = None
		from netbluemind.eas.api.SentItem import SentItem
		from netbluemind.eas.api.SentItem import __SentItemSerDer__
		__data__ = serder.ListSerDer(__SentItemSerDer__()).encode(sentItems)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def needReset (self, folderId , account ):
		postUri = "/_needReset/{folderId}";
		__data__ = None
		postUri = postUri.replace("{folderId}",folderId);
		from netbluemind.eas.api.Account import Account
		from netbluemind.eas.api.Account import __AccountSerDer__
		__data__ = __AccountSerDer__().encode(account)

		queryParams = {    };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.BOOLEAN, response)
	def getConfiguration (self):
		postUri = "/_getConfiguration";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.MapSerDer(serder.STRING), response)
	def isKnownClientId (self, clientId ):
		postUri = "/_sendmailId/{clientId}";
		__data__ = None
		postUri = postUri.replace("{clientId}",clientId);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.BOOLEAN, response)
	def resetSentItems (self, folderId , account ):
		postUri = "/_resetSentItems/{folderId}";
		__data__ = None
		postUri = postUri.replace("{folderId}",folderId);
		from netbluemind.eas.api.Account import Account
		from netbluemind.eas.api.Account import __AccountSerDer__
		__data__ = __AccountSerDer__().encode(account)

		queryParams = {    };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def insertClientId (self, clientId ):
		postUri = "/_sendmailId/{clientId}";
		__data__ = None
		postUri = postUri.replace("{clientId}",clientId);
		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IEas_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IInstantMessaging_VERSION = "3.1.28078"

class IInstantMessaging(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/im'

	def getLastMessagesBetween (self, user1 , user2 , messagesCount ):
		postUri = "/_getLastMessagesBetween";
		__data__ = None
		queryParams = {  'user1': user1  , 'user2': user2  , 'messagesCount': messagesCount   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstantMessaging_VERSION}, data = json.dumps(__data__));
		from netbluemind.im.api.IMMessage import IMMessage
		from netbluemind.im.api.IMMessage import __IMMessageSerDer__
		return self.handleResult__(serder.ListSerDer(__IMMessageSerDer__()), response)
	def isActiveUser (self, uid ):
		postUri = "/_activeUser/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstantMessaging_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.BOOLEAN, response)
	def sendGroupChatHistory (self, sender , groupChatId , recipients ):
		postUri = "/_sendGroupChatHistory/{groupChatId}";
		__data__ = None
		postUri = postUri.replace("{groupChatId}",groupChatId);
		__data__ = serder.ListSerDer(serder.STRING).encode(recipients)

		queryParams = {  'sender': sender     };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstantMessaging_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def setRoster (self, jabberId , data ):
		postUri = "/_setRoster";
		__data__ = None
		__data__ = serder.STRING.encode(data)

		queryParams = {  'jabberId': jabberId    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstantMessaging_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getRoster (self, jabberId ):
		postUri = "/_getRoster";
		__data__ = None
		queryParams = {  'jabberId': jabberId   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstantMessaging_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.STRING, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IHSM_VERSION = "3.1.28078"

class IHSM(BaseEndpoint):
	def __init__(self, apiKey, url ,domainUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/hsm/{domainUid}'
		self.domainUid_ = domainUid
		self.base = self.base.replace('{domainUid}',domainUid)

	def setDomainPolicy (self, sp ):
		postUri = "/_setDomainPolicy";
		__data__ = None
		from netbluemind.hsm.api.StoragePolicy import StoragePolicy
		from netbluemind.hsm.api.StoragePolicy import __StoragePolicySerDer__
		__data__ = __StoragePolicySerDer__().encode(sp)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getDomainPolicy (self):
		postUri = "/_getDomainPolicy";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		from netbluemind.hsm.api.StoragePolicy import StoragePolicy
		from netbluemind.hsm.api.StoragePolicy import __StoragePolicySerDer__
		return self.handleResult__(__StoragePolicySerDer__(), response)
	def getPolicy (self, mailboxUid ):
		postUri = "/_getPolicy/{mailboxUid}";
		__data__ = None
		postUri = postUri.replace("{mailboxUid}",mailboxUid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		from netbluemind.hsm.api.StoragePolicy import StoragePolicy
		from netbluemind.hsm.api.StoragePolicy import __StoragePolicySerDer__
		return self.handleResult__(__StoragePolicySerDer__(), response)
	def setPolicy (self, mailboxUid , sp ):
		postUri = "/_setPolicy/{mailboxUid}";
		__data__ = None
		postUri = postUri.replace("{mailboxUid}",mailboxUid);
		from netbluemind.hsm.api.StoragePolicy import StoragePolicy
		from netbluemind.hsm.api.StoragePolicy import __StoragePolicySerDer__
		__data__ = __StoragePolicySerDer__().encode(sp)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def promote (self, promote ):
		postUri = "/_promote";
		__data__ = None
		from netbluemind.hsm.api.Promote import Promote
		from netbluemind.hsm.api.Promote import __PromoteSerDer__
		__data__ = __PromoteSerDer__().encode(promote)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		from netbluemind.hsm.api.TierChangeResult import TierChangeResult
		from netbluemind.hsm.api.TierChangeResult import __TierChangeResultSerDer__
		return self.handleResult__(__TierChangeResultSerDer__(), response)
	def getSize (self, mailboxUid ):
		postUri = "/_getSize/{mailboxUid}";
		__data__ = None
		postUri = postUri.replace("{mailboxUid}",mailboxUid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.DOUBLE, response)
	def demote (self, demote ):
		postUri = "/_demote";
		__data__ = None
		from netbluemind.hsm.api.Demote import Demote
		from netbluemind.hsm.api.Demote import __DemoteSerDer__
		__data__ = __DemoteSerDer__().encode(demote)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		from netbluemind.hsm.api.TierChangeResult import TierChangeResult
		from netbluemind.hsm.api.TierChangeResult import __TierChangeResultSerDer__
		return self.handleResult__(__TierChangeResultSerDer__(), response)
	def deleteDomainPolicy (self):
		postUri = "/_deleteDomainPolicy";
		__data__ = None
		queryParams = {  };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def deletePolicy (self, mailboxUid ):
		postUri = "/_deletePolicy/{mailboxUid}";
		__data__ = None
		postUri = postUri.replace("{mailboxUid}",mailboxUid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def fetch (self, mailboxUid , hsmId ):
		postUri = "/_fetch/{mailboxUid}/{hsmId}";
		__data__ = None
		postUri = postUri.replace("{mailboxUid}",mailboxUid);
		postUri = postUri.replace("{hsmId}",hsmId);
		queryParams = {    };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ByteArraySerDer, response)
	def copy (self, sourceMailboxUid , destMailboxUid , hsmIds ):
		postUri = "/_copy/{sourceMailboxUid}/{destMailboxUid}";
		__data__ = None
		postUri = postUri.replace("{sourceMailboxUid}",sourceMailboxUid);
		postUri = postUri.replace("{destMailboxUid}",destMailboxUid);
		__data__ = serder.ListSerDer(serder.STRING).encode(hsmIds)

		queryParams = {     };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHSM_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCard :
	def __init__( self):
		self.kind = None
		self.source = None
		self.identification = None
		self.deliveryAddressing = None
		self.communications = None
		self.organizational = None
		self.explanatory = None
		self.related = None
		pass

class __VCardSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCard()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.addressbook.api.VCardKind import VCardKind
		from netbluemind.addressbook.api.VCardKind import __VCardKindSerDer__
		kindValue = value['kind']
		instance.kind = __VCardKindSerDer__().parse(kindValue)
		sourceValue = value['source']
		instance.source = serder.STRING.parse(sourceValue)
		from netbluemind.addressbook.api.VCardIdentification import VCardIdentification
		from netbluemind.addressbook.api.VCardIdentification import __VCardIdentificationSerDer__
		identificationValue = value['identification']
		instance.identification = __VCardIdentificationSerDer__().parse(identificationValue)
		from netbluemind.addressbook.api.VCardDeliveryAddressing import VCardDeliveryAddressing
		from netbluemind.addressbook.api.VCardDeliveryAddressing import __VCardDeliveryAddressingSerDer__
		deliveryAddressingValue = value['deliveryAddressing']
		instance.deliveryAddressing = serder.ListSerDer(__VCardDeliveryAddressingSerDer__()).parse(deliveryAddressingValue)
		from netbluemind.addressbook.api.VCardCommunications import VCardCommunications
		from netbluemind.addressbook.api.VCardCommunications import __VCardCommunicationsSerDer__
		communicationsValue = value['communications']
		instance.communications = __VCardCommunicationsSerDer__().parse(communicationsValue)
		from netbluemind.addressbook.api.VCardOrganizational import VCardOrganizational
		from netbluemind.addressbook.api.VCardOrganizational import __VCardOrganizationalSerDer__
		organizationalValue = value['organizational']
		instance.organizational = __VCardOrganizationalSerDer__().parse(organizationalValue)
		from netbluemind.addressbook.api.VCardExplanatory import VCardExplanatory
		from netbluemind.addressbook.api.VCardExplanatory import __VCardExplanatorySerDer__
		explanatoryValue = value['explanatory']
		instance.explanatory = __VCardExplanatorySerDer__().parse(explanatoryValue)
		from netbluemind.addressbook.api.VCardRelated import VCardRelated
		from netbluemind.addressbook.api.VCardRelated import __VCardRelatedSerDer__
		relatedValue = value['related']
		instance.related = __VCardRelatedSerDer__().parse(relatedValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.addressbook.api.VCardKind import VCardKind
		from netbluemind.addressbook.api.VCardKind import __VCardKindSerDer__
		kindValue = value.kind
		instance["kind"] = __VCardKindSerDer__().encode(kindValue)
		sourceValue = value.source
		instance["source"] = serder.STRING.encode(sourceValue)
		from netbluemind.addressbook.api.VCardIdentification import VCardIdentification
		from netbluemind.addressbook.api.VCardIdentification import __VCardIdentificationSerDer__
		identificationValue = value.identification
		instance["identification"] = __VCardIdentificationSerDer__().encode(identificationValue)
		from netbluemind.addressbook.api.VCardDeliveryAddressing import VCardDeliveryAddressing
		from netbluemind.addressbook.api.VCardDeliveryAddressing import __VCardDeliveryAddressingSerDer__
		deliveryAddressingValue = value.deliveryAddressing
		instance["deliveryAddressing"] = serder.ListSerDer(__VCardDeliveryAddressingSerDer__()).encode(deliveryAddressingValue)
		from netbluemind.addressbook.api.VCardCommunications import VCardCommunications
		from netbluemind.addressbook.api.VCardCommunications import __VCardCommunicationsSerDer__
		communicationsValue = value.communications
		instance["communications"] = __VCardCommunicationsSerDer__().encode(communicationsValue)
		from netbluemind.addressbook.api.VCardOrganizational import VCardOrganizational
		from netbluemind.addressbook.api.VCardOrganizational import __VCardOrganizationalSerDer__
		organizationalValue = value.organizational
		instance["organizational"] = __VCardOrganizationalSerDer__().encode(organizationalValue)
		from netbluemind.addressbook.api.VCardExplanatory import VCardExplanatory
		from netbluemind.addressbook.api.VCardExplanatory import __VCardExplanatorySerDer__
		explanatoryValue = value.explanatory
		instance["explanatory"] = __VCardExplanatorySerDer__().encode(explanatoryValue)
		from netbluemind.addressbook.api.VCardRelated import VCardRelated
		from netbluemind.addressbook.api.VCardRelated import __VCardRelatedSerDer__
		relatedValue = value.related
		instance["related"] = __VCardRelatedSerDer__().encode(relatedValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class MailFilterVacation :
	def __init__( self):
		self.enabled = None
		self.start = None
		self.end = None
		self.text = None
		self.subject = None
		pass

class __MailFilterVacationSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = MailFilterVacation()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		enabledValue = value['enabled']
		instance.enabled = serder.BOOLEAN.parse(enabledValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		startValue = value['start']
		instance.start = __BmDateTimeSerDer__().parse(startValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		endValue = value['end']
		instance.end = __BmDateTimeSerDer__().parse(endValue)
		textValue = value['text']
		instance.text = serder.STRING.parse(textValue)
		subjectValue = value['subject']
		instance.subject = serder.STRING.parse(subjectValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		enabledValue = value.enabled
		instance["enabled"] = serder.BOOLEAN.encode(enabledValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		startValue = value.start
		instance["start"] = __BmDateTimeSerDer__().encode(startValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		endValue = value.end
		instance["end"] = __BmDateTimeSerDer__().encode(endValue)
		textValue = value.text
		instance["text"] = serder.STRING.encode(textValue)
		subjectValue = value.subject
		instance["subject"] = serder.STRING.encode(subjectValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class CalendarLookupResponse :
	def __init__( self):
		self.uid = None
		self.name = None
		self.type = None
		self.email = None
		self.memberCount = None
		self.ownerUid = None
		pass

class __CalendarLookupResponseSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = CalendarLookupResponse()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		uidValue = value['uid']
		instance.uid = serder.STRING.parse(uidValue)
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		from netbluemind.calendar.api.CalendarLookupResponseType import CalendarLookupResponseType
		from netbluemind.calendar.api.CalendarLookupResponseType import __CalendarLookupResponseTypeSerDer__
		typeValue = value['type']
		instance.type = __CalendarLookupResponseTypeSerDer__().parse(typeValue)
		emailValue = value['email']
		instance.email = serder.STRING.parse(emailValue)
		memberCountValue = value['memberCount']
		instance.memberCount = serder.INT.parse(memberCountValue)
		ownerUidValue = value['ownerUid']
		instance.ownerUid = serder.STRING.parse(ownerUidValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		uidValue = value.uid
		instance["uid"] = serder.STRING.encode(uidValue)
		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		from netbluemind.calendar.api.CalendarLookupResponseType import CalendarLookupResponseType
		from netbluemind.calendar.api.CalendarLookupResponseType import __CalendarLookupResponseTypeSerDer__
		typeValue = value.type
		instance["type"] = __CalendarLookupResponseTypeSerDer__().encode(typeValue)
		emailValue = value.email
		instance["email"] = serder.STRING.encode(emailValue)
		memberCountValue = value.memberCount
		instance["memberCount"] = serder.INT.encode(memberCountValue)
		ownerUidValue = value.ownerUid
		instance["ownerUid"] = serder.STRING.encode(ownerUidValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

ISecurityMgmt_VERSION = "3.1.28078"

class ISecurityMgmt(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/system/security'

	def updateFirewallRules (self):
		postUri = "/_updatefirewallrules";
		__data__ = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ISecurityMgmt_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def updateCertificate (self, certData ):
		postUri = "";
		__data__ = None
		from netbluemind.system.api.CertData import CertData
		from netbluemind.system.api.CertData import __CertDataSerDer__
		__data__ = __CertDataSerDer__().encode(certData)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ISecurityMgmt_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
